;HardwareTest.ASM
*******************************************************************************
*REVISION HISTORY:
*
*DATE			REV. NO.	DESCRIPTION
*
*May 24, 2005		1.00		Initial release
*
*
*Author: Exequiel Rarama for the neCore12M64
*******************************************************************************
;Assembled using CW
;
; ---------------------------
; Demo - HardwareTest Routine
; ---------------------------

	include "NE64Regs.INC"

;Public Function
	XDEF HardwareTestGo
	XDEF HardwareTestInit
	XDEF HardwareReady

;Public Variables
	XDEF hardware_state
	XDEF testFlag

;Public Tones

;External Function
	XREF SerOutput0
	XREF OutStr0	

	XREF SendDecByte		;Hex to Decimal conversion


;External Variables

	XREF adflag

DataSec:SECTION
Var		ds	3
hardware_state	ds	2
count		ds	1
Error		ds	1
testFlag	ds	1
PassFailFlag	ds	1

;

PUPAE		equ	%00000001		;Port A pullup
PUPBE		equ	%00000010
PUPEE		equ	%00010000
PUPKE		equ	%10000000

switch		equ	%01000000		;Port A bit 6

;***********************************************************************************************
NON_BANKED:SECTION
;
HardwareTestInit				;Testing the Hardware ports
	bset	PUCR,PUPAE+PUPBE+PUPEE+PUPKE	;Enable all pull up's

	movb	#$FF,PERT
	movb	#$FF,PERS
	movb	#$FF,PERJ

	movw	#HardwareReady,hardware_state
	clr	testFlag
	clr	PassFailFlag

goEx
	rts

HardwareReady
	rts


HardwareTestGo
	movw	#WaitForChar,hardware_state

	ldx	#WarningMSG2
	jsr	OutStr0
	movb	#1,testFlag

	clr	PassFailFlag
	rts

WaitForChar
	ldaa	testFlag
	bne	WaitForCharEx

	movw	#HardwareTestTJAD,hardware_state
	clr	PassFailFlag

WaitForCharEx
	rts

;----------------------------------------------------------------------------------------------
;Start checking on Port T and J driving AD
;Disable Analog To Digital
;
HardwareTestTJAD
	movb	#$00,ATDCTL2	        ;enable ATD
	movb	#$00,ATDCTL3	        ;8 Channels ATD result
	movb	#$00,ATDCTL4		;Select Sample rate
	movb	#$00,ATDCTL5		;Select 8 channel mode, Continuous scan
	movb	#1,adflag

	movb	#$FF,ATDDIEN		;Enable ATD channel as Digital input

	ldx	#TestMSG4
	jsr	OutStr0

	clr	Error

	movb	#$00,DDRS		;Make sure these are inputs
	movb	#$00,DDRH
	movb	#$00,DDRG
	movb	#$00,DDRT
	movb	#$00,DDRJ

	movb	#$F0,DDRT		;make Port T o/p
	movb	#$0F,DDRJ		;make Port J o/p

	movb	#1,Var			;Initialize to 1st bit
	movb	#9,Var+1		;Initialize counter	
	bra	CheckPortAD20

CheckPortAD10
	lsl	Var

CheckPortAD20
	dec	Var+1
	beq	CheckPortADDone

	movb	Var,PORTT
	movb	Var,PORTJ

	jsr	littleDelay		;delay to allow sw pin to pull up

	ldab	PTAD
	ldab	PTAD

	cmpb	Var
	beq	CheckPortAD10

	ldx	#Error2
	jsr	OutStr0

	ldab	Var
	jsr	SendDecByte		;Convert Value

	ldx	#Error3
	jsr	OutStr0

	ldab	PORTS
	jsr	SendDecByte		;Convert Value

	movb	#1,Error		;Set error flag
	inc	PassFailFlag		;Error increment flag

	bra	CheckPortAD10		;Go continue the test

CheckPortADDone
	ldaa	Error
	beq	CheckPortADDoneEx10

	ldx	#Error6
	jsr	OutStr0
	bra	CheckPortADDoneEx

CheckPortADDoneEx10
	ldx	#TestMSG3
	jsr	OutStr0

CheckPortADDoneEx
	movb	#$80,ATDCTL2	        ;enable ATD
	movb	#$40,ATDCTL3	        ;8 Channels ATD result
	movb	#$60,ATDCTL4		;Select Sample rate
	movb	#$B0,ATDCTL5		;Select 8 channel mode, Continuous scan
	movb	#$00,ATDDIEN		;Disable ATD channel as Digital input
	clr	adflag

	movb	#$00,DDRT		;make Port T i/p
	movb	#$00,DDRJ		;make Port J i/p

	movw	#HardwareTestJTS,hardware_state
	rts

;---------------------------------------------------------------------------------------------
;Start Testing Port T and J driving Port S
;
HardwareTestJTS
	movb	#$00,DDRS		;Make sure these are inputs
	movb	#$00,DDRH
	movb	#$00,DDRG
	movb	#$00,DDRT		;make Port T i/p
	movb	#$00,DDRJ		;make Port J i/p

	movb	#$F0,DDRT		;make Port T o/p
	movb	#$0C,DDRJ		;make Port J o/p

	ldx	#TestMSG5
	jsr	OutStr0

	clr	Error

	movb	#4,Var			;Initialize to 1st bit
	movb	#7,Var+1		;Initialize counter	
	bra	CheckPortS20

CheckPortS10
	lsl	Var

CheckPortS20
	dec	Var+1
	beq	CheckPortSDone

	movb	Var,PORTT
	movb	Var,PORTJ

	jsr	littleDelay		;delay to allow sw pin to pull up

	ldab	PORTS
	ldab	PORTS
	andb	#%11111100

	cmpb	Var
	beq	CheckPortS10

	ldx	#Error2
	jsr	OutStr0

	ldab	Var
	jsr	SendDecByte		;Convert Value

	ldx	#Error3
	jsr	OutStr0

	ldab	PORTS
	andb	#%11111100
	jsr	SendDecByte		;Convert Value

	movb	#1,Error		;Set error flag
	inc	PassFailFlag		;Error increment flag

	bra	CheckPortS10		;Go continue the test

CheckPortSDone
	ldaa	Error
	beq	CheckPortSDoneEx10

	ldx	#Error7
	jsr	OutStr0
	bra	CheckPortSDoneEx

CheckPortSDoneEx10
	ldx	#TestMSG3
	jsr	OutStr0


CheckPortSDoneEx
	movb	#$00,DDRT		;make Port T i/p
	movb	#$00,DDRJ		;make Port J i/p

	movw	#HardwareTestST,hardware_state
	rts

;---------------------------------------------------------------------------------------------
;Start Testing Port S bit 4, 5, 6,  and 7 driving Port T bit 4, 5, 6,  and 7
;
HardwareTestST
	movb	#$00,DDRS		;Make sure these are inputs
	movb	#$00,DDRH
	movb	#$00,DDRG
	movb	#$00,DDRT
	movb	#$00,DDRJ

	movb	#$F0,DDRS		;make Port S o/p
	movb	#$00,DDRT		;make Port T i/p

	ldx	#TestMSG6
	jsr	OutStr0

	clr	Error

	movb	#16,Var		;Initialize to 1st bit
	movb	#5,Var+1		;Initialize counter	
	bra	CheckPortT20

CheckPortT10
	lsl	Var

CheckPortT20
	dec	Var+1
	beq	CheckPortTDone

	movb	Var,PORTS

	jsr	littleDelay		;delay to allow sw pin to pull up

	ldab	PORTT
	ldab	PORTT
	andb	#%11110000

	cmpb	Var
	beq	CheckPortT10

	ldx	#Error2
	jsr	OutStr0

	ldab	Var
	jsr	SendDecByte		;Convert Value

	ldx	#Error3
	jsr	OutStr0

	ldab	PORTT
	andb	#%11110000
	jsr	SendDecByte		;Convert Value

	movb	#1,Error		;Set error flag
	inc	PassFailFlag		;Error increment flag

	bra	CheckPortT10		;Go continue the test

CheckPortTDone
	ldaa	Error
	beq	CheckPortTDoneEx10

	ldx	#Error8
	jsr	OutStr0
	bra	CheckPortTDoneEx

CheckPortTDoneEx10
	ldx	#TestMSG3
	jsr	OutStr0


CheckPortTDoneEx
	movb	#$00,DDRS		;make Port S i/p

	movw	#HardwareTestSJ,hardware_state
	rts

;---------------------------------------------------------------------------------------------
;Start Testing Port S bit 2, and 3 driving Port J bit 2 and 3
;
HardwareTestSJ
	movb	#$00,DDRS		;Make sure these are inputs
	movb	#$00,DDRH
	movb	#$00,DDRG
	movb	#$00,DDRT
	movb	#$00,DDRJ

	movb	#$0C,DDRS		;make Port S o/p
	movb	#$00,DDRJ		;make Port J i/p

	ldx	#TestMSG7
	jsr	OutStr0

	clr	Error

	movb	#4,Var			;Initialize to 1st bit
	movb	#3,Var+1		;Initialize counter	
	bra	CheckPortJ20

CheckPortJ10
	lsl	Var

CheckPortJ20
	dec	Var+1
	beq	CheckPortJDone

	movb	Var,PORTS

	jsr	littleDelay		;delay to allow sw pin to pull up

	ldab	PORTJ
	ldab	PORTJ
	andb	#%00001100

	cmpb	Var
	beq	CheckPortJ10

	ldx	#Error2
	jsr	OutStr0

	ldab	Var
	jsr	SendDecByte		;Convert Value

	ldx	#Error3
	jsr	OutStr0

	ldab	PORTJ
	ldab	PORTJ
	andb	#%00001100
	jsr	SendDecByte		;Convert Value

	movb	#1,Error		;Set error flag
	inc	PassFailFlag		;Error increment flag

	bra	CheckPortJ10		;Go continue the test

CheckPortJDone
	ldaa	Error
	beq	CheckPortJDoneEx10

	ldx	#Error9
	jsr	OutStr0
	bra	CheckPortJDoneEx

CheckPortJDoneEx10
	ldx	#TestMSG3
	jsr	OutStr0


CheckPortJDoneEx
	movb	#$00,DDRS		;make Port S i/p
	movw	#HardwareTestTJ,hardware_state
	rts

;---------------------------------------------------------------------------------------------
;Start Testing Port T bit 6 and 7 driving Port J bit 6 and 7
;
HardwareTestTJ
	movb	#$00,DDRS		;Make sure these are inputs
	movb	#$00,DDRH
	movb	#$00,DDRG
	movb	#$00,DDRT
	movb	#$00,DDRJ

	movb	#$C0,DDRT		;make Port T o/p
	movb	#$00,DDRJ		;make Port J i/p

	ldx	#TestMSG8
	jsr	OutStr0

	clr	Error

	movb	#$40,Var			;Initialize to 1st bit
	movb	#3,Var+1		;Initialize counter	
	bra	CheckPortJJ20

CheckPortJJ10
	lsl	Var

CheckPortJJ20
	dec	Var+1
	beq	CheckPortJJDone

	movb	Var,PORTT

	jsr	littleDelay		;delay to allow sw pin to pull up

	ldab	PORTJ
	ldab	PORTJ
	andb	#%11000000

	cmpb	Var
	beq	CheckPortJJ10

	ldx	#Error2
	jsr	OutStr0

	ldab	Var
	jsr	SendDecByte		;Convert Value

	ldx	#Error3
	jsr	OutStr0

	ldab	PORTJ
	ldab	PORTJ
	andb	#%11000000
	jsr	SendDecByte		;Convert Value

	movb	#1,Error		;Set error flag
	inc	PassFailFlag		;Error increment flag

	bra	CheckPortJJ10		;Go continue the test

CheckPortJJDone
	ldaa	Error
	beq	CheckPortJJDoneEx10

	ldx	#Error10
	jsr	OutStr0
	bra	CheckPortJJDoneEx

CheckPortJJDoneEx10
	ldx	#TestMSG3
	jsr	OutStr0


CheckPortJJDoneEx
	movb	#$00,DDRT		;make Port T i/p

	movw	#HardwareTestJT,hardware_state
	rts


;---------------------------------------------------------------------------------------------
;Start Testing Port J bit 6 and 7 driving Port T bit 6 and 7
;
HardwareTestJT
	movb	#$00,DDRS		;Make sure these are inputs
	movb	#$00,DDRH
	movb	#$00,DDRG
	movb	#$00,DDRT
	movb	#$00,DDRJ

	movb	#$C0,DDRJ		;make Port J o/p
	movb	#$00,DDRT		;make Port T i/p

	ldx	#TestMSG9
	jsr	OutStr0

	clr	Error

	movb	#$40,Var			;Initialize to 1st bit
	movb	#3,Var+1		;Initialize counter	
	bra	CheckPortTT20

CheckPortTT10
	lsl	Var

CheckPortTT20
	dec	Var+1
	beq	CheckPortTTDone

	movb	Var,PORTJ

	jsr	littleDelay		;delay to allow sw pin to pull up

	ldab	PORTT
	ldab	PORTT
	andb	#%11000000

	cmpb	Var
	beq	CheckPortTT10

	ldx	#Error2
	jsr	OutStr0

	ldab	Var
	jsr	SendDecByte		;Convert Value

	ldx	#Error3
	jsr	OutStr0

	ldab	PORTT
	ldab	PORTT
	andb	#%11000000
	jsr	SendDecByte		;Convert Value

	movb	#1,Error		;Set error flag
	inc	PassFailFlag		;Error increment flag

	bra	CheckPortTT10		;Go continue the test

CheckPortTTDone
	ldaa	Error
	beq	CheckPortTTDoneEx10

	ldx	#Error11
	jsr	OutStr0
	bra	CheckPortTTDoneEx

CheckPortTTDoneEx10
	ldx	#TestMSG3
	jsr	OutStr0


CheckPortTTDoneEx
	movb	#$00,DDRJ		;make Port J i/p

	movw	#HardwareTestJG,hardware_state
	rts

;---------------------------------------------------------------------------------------------
;Start Testing Port J bit 0, 1, and 2 driving Port G bit 0, 1, and 2
;
HardwareTestJG
	movb	#$00,DDRS		;Make sure these are inputs
	movb	#$00,DDRH
	movb	#$00,DDRG
	movb	#$00,DDRT
	movb	#$00,DDRJ

	movb	#$07,DDRJ		;make Port J o/p
	movb	#$00,DDRG		;make Port G i/p

	ldx	#TestMSG10
	jsr	OutStr0

	clr	Error

	movb	#$01,Var			;Initialize to 1st bit
	movb	#4,Var+1		;Initialize counter	
	bra	CheckPortG20

CheckPortG10
	lsl	Var

CheckPortG20
	dec	Var+1
	beq	CheckPortGDone

	movb	Var,PORTJ

	jsr	littleDelay		;delay to allow sw pin to pull up

	ldab	PORTG
	ldab	PORTG
	andb	#%00000111

	cmpb	Var
	beq	CheckPortG10

	ldx	#Error2
	jsr	OutStr0

	ldab	Var
	jsr	SendDecByte		;Convert Value

	ldx	#Error3
	jsr	OutStr0

	ldab	PORTG
	ldab	PORTG
	andb	#%00000111
	jsr	SendDecByte		;Convert Value

	movb	#1,Error		;Set error flag
	inc	PassFailFlag		;Error increment flag

	bra	CheckPortG10		;Go continue the test

CheckPortGDone
	ldaa	Error
	beq	CheckPortGDoneEx10

	ldx	#Error12
	jsr	OutStr0
	bra	CheckPortGDoneEx

CheckPortGDoneEx10
	ldx	#TestMSG3
	jsr	OutStr0


CheckPortGDoneEx
	movb	#$00,DDRJ		;make Port J i/p

	movw	#HardwareTestGJ,hardware_state
	rts

;---------------------------------------------------------------------------------------------
;Start Testing Port G bit 0, 1, and 2 driving Port J bit 0, 1, and 2
;
HardwareTestGJ
	movb	#$00,DDRS		;Make sure these are inputs
	movb	#$00,DDRH
	movb	#$00,DDRG
	movb	#$00,DDRT
	movb	#$00,DDRJ

	movb	#$07,DDRG		;make Port G o/p
	movb	#$00,DDRJ		;make Port J i/p

	ldx	#TestMSG11
	jsr	OutStr0

	clr	Error

	movb	#$01,Var			;Initialize to 1st bit
	movb	#4,Var+1		;Initialize counter	
	bra	CheckPortJJJ20

CheckPortJJJ10
	lsl	Var

CheckPortJJJ20
	dec	Var+1
	beq	CheckPortJJJDone

	movb	Var,PORTG

	jsr	littleDelay		;delay to allow sw pin to pull up

	ldab	PORTJ
	ldab	PORTJ
	andb	#%00000111

	cmpb	Var
	beq	CheckPortJJJ10

	ldx	#Error2
	jsr	OutStr0

	ldab	Var
	jsr	SendDecByte		;Convert Value

	ldx	#Error3
	jsr	OutStr0

	ldab	PORTJ
	ldab	PORTJ
	andb	#%00000111
	jsr	SendDecByte		;Convert Value

	movb	#1,Error		;Set error flag
	inc	PassFailFlag		;Error increment flag

	bra	CheckPortJJJ10		;Go continue the test

CheckPortJJJDone
	ldaa	Error
	beq	CheckPortJJJDoneEx10

	ldx	#Error13
	jsr	OutStr0
	bra	CheckPortJJJDoneEx

CheckPortJJJDoneEx10
	ldx	#TestMSG3
	jsr	OutStr0


CheckPortJJJDoneEx
	movb	#$00,DDRG		;make Port J i/p

	movw	#HardwareTestTH,hardware_state
	rts

;---------------------------------------------------------------------------------------------
;Start Testing Port T bit 5 and 6 driving Port H bit 5 and 6
;
HardwareTestTH
	movb	#$00,DDRS		;Make sure these are inputs
	movb	#$00,DDRH
	movb	#$00,DDRG
	movb	#$00,DDRT
	movb	#$00,DDRJ

	movb	#$60,DDRT		;make Port T o/p
	movb	#$00,DDRH		;make Port H i/p

	ldx	#TestMSG12
	jsr	OutStr0

	clr	Error

	movb	#$20,Var			;Initialize to 1st bit
	movb	#3,Var+1		;Initialize counter	
	bra	CheckPortH20

CheckPortH10
	lsl	Var

CheckPortH20
	dec	Var+1
	beq	CheckPortHDone

	movb	Var,PORTT

	jsr	littleDelay		;delay to allow sw pin to pull up

	ldab	PORTH
	ldab	PORTH
	andb	#%01100000

	cmpb	Var
	beq	CheckPortH10

	ldx	#Error2
	jsr	OutStr0

	ldab	Var
	jsr	SendDecByte		;Convert Value

	ldx	#Error3
	jsr	OutStr0

	ldab	PORTH
	ldab	PORTH
	andb	#%01100000
	jsr	SendDecByte		;Convert Value

	movb	#1,Error		;Set error flag
	inc	PassFailFlag		;Error increment flag

	bra	CheckPortH10		;Go continue the test

CheckPortHDone
	ldaa	Error
	beq	CheckPortHDoneEx10

	ldx	#Error14
	jsr	OutStr0
	bra	CheckPortHDoneEx

CheckPortHDoneEx10
	ldx	#TestMSG3
	jsr	OutStr0


CheckPortHDoneEx
	movb	#$00,DDRT		;make Port T i/p

	movw	#HardwareTestHT,hardware_state
	rts

;---------------------------------------------------------------------------------------------
;Start Testing Port H bit 5 and 6 driving Port T bit 5 and 6
;
HardwareTestHT
	movb	#$00,DDRS		;Make sure these are inputs
	movb	#$00,DDRH
	movb	#$00,DDRG
	movb	#$00,DDRT
	movb	#$00,DDRJ

	movb	#$60,DDRH		;make Port H o/p
	movb	#$00,DDRT		;make Port T i/p

	ldx	#TestMSG13
	jsr	OutStr0

	clr	Error

	movb	#$20,Var			;Initialize to 1st bit
	movb	#3,Var+1		;Initialize counter	
	bra	CheckPortTTT20

CheckPortTTT10
	lsl	Var

CheckPortTTT20
	dec	Var+1
	beq	CheckPortTTTDone

	movb	Var,PORTH

	jsr	littleDelay		;delay to allow sw pin to pull up

	ldab	PORTT
	ldab	PORTT
	andb	#%01100000

	cmpb	Var
	beq	CheckPortTTT10

	ldx	#Error2
	jsr	OutStr0

	ldab	Var
	jsr	SendDecByte		;Convert Value

	ldx	#Error3
	jsr	OutStr0

	ldab	PORTT
	ldab	PORTT
	andb	#%01100000
	jsr	SendDecByte		;Convert Value

	movb	#1,Error		;Set error flag
	inc	PassFailFlag		;Error increment flag

	bra	CheckPortTTT10		;Go continue the test

CheckPortTTTDone
	ldaa	Error
	beq	CheckPortTTTDoneEx10

	ldx	#Error15
	jsr	OutStr0
	bra	CheckPortTTTDoneEx

CheckPortTTTDoneEx10
	ldx	#TestMSG3
	jsr	OutStr0


CheckPortTTTDoneEx
	movb	#$00,DDRH		;make Port H i/p

	movw	#HardwareTestJH,hardware_state
	rts

;---------------------------------------------------------------------------------------------
;Start Testing Port J bit 0 driving Port H bit 0 Low
;
HardwareTestJH
	movb	#$00,DDRS		;Make sure these are inputs
	movb	#$00,DDRH
	movb	#$00,DDRG
	movb	#$00,DDRT
	movb	#$00,DDRJ

	movb	#$1,DDRJ		;make Port J o/p
	movb	#$00,DDRH		;make Port H i/p

	ldx	#TestMSG14
	jsr	OutStr0

	clr	Error

	movb	#0,PORTJ
	clr	Var

	jsr	littleDelay		;delay to allow sw pin to pull up

	ldab	PORTH
	ldab	PORTH
	andb	#%00000001

	cmpb	Var
	beq	CheckPortHH10

	ldx	#Error2
	jsr	OutStr0

	ldab	Var
	jsr	SendDecByte		;Convert Value

	ldx	#Error3
	jsr	OutStr0

	ldab	PORTH
	ldab	PORTH
	andb	#%00000001
	jsr	SendDecByte		;Convert Value

	movb	#1,Error		;Set error flag
	inc	PassFailFlag		;Error increment flag

CheckPortHH10
	ldaa	Error
	beq	CheckPortHHDoneEx10

	ldx	#Error16
	jsr	OutStr0
	bra	CheckPortHHDoneEx

CheckPortHHDoneEx10
	ldx	#TestMSG3
	jsr	OutStr0


CheckPortHHDoneEx
	movb	#$00,DDRJ		;make Port J i/p
	movw	#HardwareTestJhH,hardware_state
	rts

;---------------------------------------------------------------------------------------------
;Start Testing Port J bit 0 driving Port H bit 0 High
;
HardwareTestJhH
	movb	#$00,DDRS		;Make sure these are inputs
	movb	#$00,DDRH
	movb	#$00,DDRG
	movb	#$00,DDRT
	movb	#$00,DDRJ

	movb	#$1,DDRJ		;make Port J o/p
	movb	#$00,DDRH		;make Port H i/p

	ldx	#TestMSG15
	jsr	OutStr0

	clr	Error

	movb	#1,PORTJ
	movb	#1,Var

	jsr	littleDelay		;delay to allow sw pin to pull up

	ldab	PORTH
	ldab	PORTH
	andb	#%00000001

	cmpb	Var
	beq	CheckPortHHH10

	ldx	#Error2
	jsr	OutStr0

	ldab	Var
	jsr	SendDecByte		;Convert Value

	ldx	#Error3
	jsr	OutStr0

	ldab	PORTH
	ldab	PORTH
	andb	#%00000001
	jsr	SendDecByte		;Convert Value

	movb	#1,Error		;Set error flag
	inc	PassFailFlag		;Error increment flag

CheckPortHHH10
	ldaa	Error
	beq	CheckPortHHHDoneEx10

	ldx	#Error16
	jsr	OutStr0
	bra	CheckPortHHHDoneEx

CheckPortHHHDoneEx10
	ldx	#TestMSG3
	jsr	OutStr0

CheckPortHHHDoneEx
	movb	#$00,DDRJ		;make Port J i/p

;	movw	#HardwareTestJT,hardware_state
;	rts


;------------------------
;ExitB
;	ldaa	Error
;	bne	ExitTest

;	ldx	#TestMSG3
;	jsr	OutStr0


ExitTest
	ldaa	PassFailFlag		;Error increment flag
	beq	ExitTest10

	ldx	#HardwareFailed
	jsr	OutStr0
	bra	ExitTest20

ExitTest10
	ldx	#HardwarePass
	jsr	OutStr0

ExitTest20
	movw	#HardwareReady,hardware_state
	ldx	#WarningMSG3
	jsr	OutStr0
	rts


littleDelay
	pshb	
	clrb
	dbne	b,*         		  ;delay to allow sw pin to pull up
	pulb
	rts

;----------------------------------------------------------------------------------------------
WarningMSG2	dc.b	$D,$A,'Press Any Key when READY',$D,$A,0
WarningMSG3	dc.b	$D,$A,'Press RESET when DONE',$D,$A,0
HardwareFailed	dc.b	$D,$A,'Port TEST = FAILED',$D,$A,0
HardwarePass	dc.b	$D,$A,'Port TEST = PASS',$D,$A,0

TestMSG3	dc.b	'Pass',$D,$A,0

TestMSG4	dc.b	$D,$A,'Test ->Port T and J driving Port AD',$D,$A,0
TestMSG5	dc.b	$D,$A,'Test ->Port T and J driving Port S',$D,$A,0

TestMSG6	dc.b	$D,$A,'Test ->Port S bit 4,5,6 and 7 driving Port T bit 4,5,6 and 7',$D,$A,0
TestMSG7	dc.b	$D,$A,'Test ->Port S bit 2 and 3 driving Port J bit 2 and 3',$D,$A,0

TestMSG8	dc.b	$D,$A,'Test ->Port T bit 6 and 7 driving Port J bit 6 and 7',$D,$A,0
TestMSG9	dc.b	$D,$A,'Test ->Port J bit 6 and 7 driving Port T bit 6 and 7',$D,$A,0

TestMSG10	dc.b	$D,$A,'Test ->Port J bit 0,1, and 2 driving Port G bit 0, 1, and 2',$D,$A,0
TestMSG11	dc.b	$D,$A,'Test ->Port G bit 0,1, and 2 driving Port J bit 0, 1, and 2',$D,$A,0

TestMSG12	dc.b	$D,$A,'Test ->Port T bit 5 and 6 driving Port H bit 5 and 6',$D,$A,0
TestMSG13	dc.b	$D,$A,'Test ->Port H bit 5 and 6 driving Port T bit 5 and 6',$D,$A,0

TestMSG14	dc.b	$D,$A,'Test ->Port J bit 0 driving Port H bit 0 Low',$D,$A,0
TestMSG15	dc.b	$D,$A,'Test ->Port J bit 0 driving Port H bit 0 High',$D,$A,0


Error1		dc.b	$D,$A,'Fail ->Port A driving Port B on H2',$D,$A,0
Error2		dc.b	$D,$A,'Sent    ',0
Error3		dc.b	$D,$A,'Receive ',0

Error4		dc.b	$D,$A,'Fail ->Port M bit 0 driving Port E bit 0 High',$D,$A,0
Error5		dc.b	$D,$A,'Fail ->Port M bit 1 driving Port E bit 1 High',$D,$A,0
Error5a		dc.b	$D,$A,'Fail ->Port M driving Port E ',$D,$A,0

Error6		dc.b	$D,$A,'Fail ->Port T and J driving Port AD',$D,$A,0
Error7		dc.b	$D,$A,'Fail ->Port T and J driving Port S',$D,$A,0

Error8		dc.b	$D,$A,'Fail ->Port S bit 4,5,6 and 7 driving Port T bit 4,5,6 and 7',$D,$A,0
Error9		dc.b	$D,$A,'Fail ->Port S bit 2 and 3 driving Port J bit 2 and 3',$D,$A,0

Error10		dc.b	$D,$A,'Fail ->Port T bit 6 and 7 driving Port J bit 6 and 7',$D,$A,0
Error11		dc.b	$D,$A,'Fail ->Port J bit 6 and 7 driving Port T bit 6 and 7',$D,$A,0

Error12		dc.b	$D,$A,'Fail ->Port J bit 0,1, and 2 driving Port G bit 0, 1, and 2',$D,$A,0
Error13		dc.b	$D,$A,'Fail ->Port G bit 0,1, and 2 driving Port J bit 0, 1, and 2',$D,$A,0

Error14		dc.b	$D,$A,'Fail ->Port T bit 5 and 6 driving Port H bit 5 and 6',$D,$A,0
Error15		dc.b	$D,$A,'Fail ->Port H bit 5 and 6 driving Port T bit 5 and 6',$D,$A,0

Error16		dc.b	$D,$A,'Fail ->Port J bit 0 driving Port H bit 0',$D,$A,0




	END
